# Check Standard Report for C07208

This is a summary of the measurement of C07208 made on 13 Apr 2004 by dl/mp. This measurement FAILS the checkstandard process. This device has been measured 44 times from 2000-05-01 10:17:50 to 2013-01-29 15:18:31

## Downloads

Raw_Measurement.txt | csv | xlsx
Measurement_NIST_Uncertainties.txt | csv | xlsx
Historical_Database.txt | csv | xlsx
Mean_Database.txt | csv | xlsx
Device_History.txt | csv | xlsx

## Measurement Metadata

System_Id | HP8510
System_Letter | L
Connector_Type_Calibration |
Connector_Type_Measurement | 7
Measurement_Type | 2-port
Measurement_Date | 13 Apr 2004
Measurement_Time | 19:04:37
Program_Used | 8536D
Program_Revision | 981016.1
Operator | dl/mp
Calibration_Name |
Calibration_Date |
Port_Used | 2
Number_Connects | 3
Number_Repeats | 1
Nbs | 4
Number_Frequencies | 187
Start_Frequency | 7
Device_Description | 20 db check std
Device_Id | C07208

## Raw Measurement of C07208

Figure 1. Raw measurement of C07208. The measurement of check standard C07208 in a calibrated mode.

## Plot of C07208 with uncertainty

Figure 2. Measurement of C07208. The measurement of check standard C07208 with nist total uncertainty.

## Plot Uncertainty Components

Figure 3. Uncertainty Components. The uncertainty in measurement of check standard C07208 .

## Summary of Measurement and Mean of Complete Database with Resisduals

Figure 4. Summary of Measurement and Mean with Resisduals. Data for all measurements are being used

## Measurement with Uncertainties compared with Historical Database

Figure 5. Measurement with Uncertainties compared with Historical Database. This is the current selection criteria

## The Difference of Measurement with Uncertainties compared with Historical Database

Figure 6. The Difference of Measurement with Uncertainties compared with Historical Database. This is the current selection criteria.

## The Standard Error of Measurement with Uncertainties compared with Historical Database

Figure 7. The Standard Error of Measurement with Uncertainties compared with Historical Database. This is the current selection criteria.

## The Complete History of C07208

Figure 8. Every measurement of C07208 currently in the database.

## The last 5 measurements of C07208 compared with the historical database and mean.

Figure 9. Last 5 measurements of C07208 compared with historical database and mean